#
# spec file for package jrnl
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pythons python3

Name:           jrnl
Version:        4.2.1
Release:        1.1
Summary:        Collect your thoughts and notes without leaving the command line
License:        GPL-3.0-only
URL:            https://jrnl.sh
Source0:        https://files.pythonhosted.org/packages/source/j/jrnl/jrnl-%{version}.tar.gz
Source99:       keyring_note.md
#PATCH-FIX-OPENSUSE jrnl-dateutil.patch malcolmlewis@opensuse.org -- Fix dateutil naming convention.
Patch0:         jrnl-dateutil.patch
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-pip
BuildRequires:  python3-poetry-core >= 1.0.0
## MANUAL BEGIN
Requires:       python3-colorama
Requires:       python3-cryptography
Requires:       python3-dateutil
Requires:       python3-keyring
Requires:       python3-parsedatetime
Requires:       python3-pyxdg
Requires:       python3-rich
Requires:       python3-ruamel.yaml
Requires:       python3-tzlocal
## MANUAL END
BuildArch:      noarch

%description
Simple journal application for the command line. You can use it to
easily create, search, and view journal entries. Journals are stored
as human-readable plain text, and can also be encrypted using AES
encryption.

%prep
%autosetup -p1
cp %{S:99} .

%build
%pyproject_wheel

%install
%pyproject_install
%fdupes %{buildroot}%{python_sitelib}

%files
%doc README.md keyring_note.md
%license LICENSE.md
%{_bindir}/jrnl
%{python_sitelib}/jrnl
%{python_sitelib}/jrnl-%{version}.dist-info

%changelog
* Tue Mar 11 2025 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.2.1:
  * Add Python 3.13 support (gh#jrnl-org/jrnl#1893)
  * Add calendar heatmap display format (gh#jrnl-org/jrnl#1759)
  * -contains doesn't accept multiple search terms, doesn't work with -and
    (gh#jrnl-org/jrnl#1877)
  * Tests failing on develop branch starting with pytest-bdd 7.1.2
    (gh#jrnl-org/jrnl#1875)
  * Ignore color when used in a pipeline (gh#jrnl-org/jrnl#1839)
  * Fix -contains to allow multiple terms with "OR" logic unless -and is
    added (gh#jrnl-org/jrnl#1890)
* Wed May 22 2024 malcolmlewis@opensuse.org
- Updated to version 4.1:
  + Add Python 3.12 support, (gh#jrnl-org/jrnl#1761).
  + Set new required build fields in the ReadTheDocs config file,
    (gh#jrnl-org/jrnl#1803).
  + Replace flake8 and isort with ruff linter and add black --check
    to linting step, (gh#jrnl-org/jrnl#1763).
  + Add note about messages going to stderr and the implication for
    piping, (gh#jrnl-org/jrnl#1768).
- Drop requires on ansiwrap.
- Add note about using the keyring to encrypt, (boo#1223003,
  gh#jrnl-org/jrnl#1883 and gh#marcus-h/python-keyring-keyutils#1).
* Sat Aug 19 2023 malcolmlewis@opensuse.org
- Initial build at version 4.0.1.
- Add jrnl-dateutil.patch: Fix dateutil naming convention.
